Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: runtime/bin/input_stream.dart

Issue 9500002: Rename blahHandler to onBlah throughout dart:io. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments. Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/http_impl.dart ('k') | runtime/bin/list_stream_impl.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/input_stream.dart
diff --git a/runtime/bin/input_stream.dart b/runtime/bin/input_stream.dart
index 42892950f0b2bfe6c126613ccf67893431bba931..d22464e4678b8c583781355487eb233c8690bf44 100644
--- a/runtime/bin/input_stream.dart
+++ b/runtime/bin/input_stream.dart
@@ -18,7 +18,7 @@
*
* [:
* InputStream input = ...
- * input.dataHandler = () {
+ * input.onData = () {
* var data = input.read();
* ...
* };
@@ -83,19 +83,19 @@ interface InputStream {
/**
* Sets the handler that gets called when data is available.
*/
- void set dataHandler(void callback());
+ void set onData(void callback());
/**
* Sets the handler that gets called when there will be no more data
* available in the stream.
*/
- void set closeHandler(void callback());
+ void set onClosed(void callback());
/**
* Sets the handler that gets called when the underlying
* communication channel gets into some kind of error situation.
*/
- void set errorHandler(void callback());
+ void set onError(void callback());
}
@@ -137,29 +137,29 @@ interface StringInputStream default _StringInputStream {
/**
* Sets the handler that gets called when data is available. The two
* handlers [dataHandler] and [lineHandler] are mutually exclusive
* and setting one will remove the other.
*/
- void set dataHandler(void callback());
+ void set onData(void callback());
/**
* Sets the handler that gets called when a line is available. The
* two handlers [dataHandler] and [lineHandler] are mutually
* exclusive and setting one will remove the other.
*/
- void set lineHandler(void callback());
+ void set onLine(void callback());
/**
* Sets the handler that gets called when there will be no more data
* available in the stream.
*/
- void set closeHandler(void callback());
+ void set onClosed(void callback());
/**
* Sets the handler that gets called when the underlying
* communication channel gets into some kind of error situation.
*/
- void set errorHandler(void callback());
+ void set onError(void callback());
}
@@ -202,19 +202,19 @@ interface ChunkedInputStream default _ChunkedInputStream {
* of data is available or the underlying stream has been closed and
* there is still unread data.
*/
- void set dataHandler(void callback());
+ void set onData(void callback());
/**
* Sets the handler that gets called when there will be no more data
* available in the stream.
*/
- void set closeHandler(void callback());
+ void set onClosed(void callback());
/**
* Sets the handler that gets called when the underlying
* communication channel gets into some kind of error situation.
*/
- void set errorHandler(void callback());
+ void set onError(void callback());
}
« no previous file with comments | « runtime/bin/http_impl.dart ('k') | runtime/bin/list_stream_impl.dart » ('j') | no next file with comments »
@@ -137,29 +137,29 @@ interface StringInputStream default _StringInputStream {
/**
* Sets the handler that gets called when data is available. The two
- * handlers [dataHandler] and [lineHandler] are mutually exclusive
+ * handlers [onData] and [onLine] are mutually exclusive
* and setting one will remove the other.
*/
@@ -137,29 +137,29 @@ interface StringInputStream default _StringInputStream {
/**
* Sets the handler that gets called when a line is available. The
- * two handlers [dataHandler] and [lineHandler] are mutually
+ * two handlers [onData] and [onLine] are mutually
* exclusive and setting one will remove the other.
*/

Powered by Google App Engine
This is Rietveld 408576698